<?php
	date_default_timezone_set('Europe/Paris');
	error_reporting(0);
	
	define("kErrC", "errorCode");									// Never change it! It's the key for the error code in the returned dictionary.
	define("kErrD", "errorDescription");							// Never change it! It's the key for the error description in the returned dictionary.
	define("kLogDir", dirname(__FILE__) . "/FS_Logs");				// The folder where we save the log files to. You can modify it.

	
	// We'll save the log files within this directory
	$logDirOk = createDirIfNotExisting(kLogDir);
    if($logDirOk === false){
    	// We exit with any non zero errorCode since we fail to save the Log file
    	exitWithError(10, "Logs directory missed.");
	}

	// We get the JSON dictionary containing all the parameters
	// sent by the FoldersSynchronizer application
	$dictIn = getJsonDictFromPostContent();
	if($dictIn == null){
		// We exit with any non zero errorCode since we fail to save the Log file
		exitWithError(20, "Can't find the input data.");
	}
	
	
	
	//////////////////////////////////////////////////////////////////
	// These are the parameters sent by the application FoldersSynchronizer.
	// You can use these data to save the Log files to a different folder,
	// to compose the log file filename, to send youself an email in case
	// of errors occurred during the sync/backup…
	//////////////////////////////////////////////////////////////////
	
	/*
	$postVersion = $dictIn["postVersion"] ?? 1; 					// e.g. 1. This version will be useful on the next releases.
	$postUrl = $dictIn["postUrl"] ?? ""; 							// This php file url, as e.g. https://domain.com/logs.php	
	$postTest = $dictIn["postTest"] ?? false; 						// true when you send a test from the FS Preferences panel, clicking on the button "Post Log Test"
																	// false when this php has been automatically invoked by the FS application at the end of every sync/backup
	
	$machineSerialNumber = $dictIn["machineSerialNumber"] ?? "";	// e.g. C15XKBWLND4S
	$machineMacAddress = $dictIn["machineMacAddress"] ?? "";		// e.g. F6.FF.C2.12.06.28
	
	$userName = $dictIn["userName"] ?? "";							// e.g. johns (the user logged in the computer)
	
	$taskErrorCount = $dictIn["taskErrorCount"] ?? 0;				// The amount of errors occurred during the sync/backup. 0 means no error occurred.
																	// You can use this data to save the Log file with errors within a different folder or to send yourself an email
	*/
	
	// On this sample code we just use the latest two parameters
	$now = date("Y.m.d-H.i.s");
	$taskStartTimestamp = $dictIn["taskStartTimestamp"] ?? $now;	// e.g. 2024.10.31-23.11.58 (yyyy.mm.dd-hh.ii.ss)
	$logBody = $dictIn["logBody"];									// the text of the Log
	
	//////////////////////////////////////////////////////////////////
	
	
	
	// Now we save the Log text to a file
	if($logBody)
	{
		// We compose the filename using the $taskStartTimestamp variable, e.g. FSLog_2024.10.31-23.11.58.txt
		$logFilePath = kLogDir . "/FSLog_$taskStartTimestamp.txt";	
		$bytesWritten = file_put_contents($logFilePath, $logBody);
		if($bytesWritten)
		{
			// We exit with the errorCode 0 since we succeeded!!!
			exitWithError(0, "Log file properly saved.");			// MANDATORY!!!
		}
	}
	
	// We exit with any non zero errorCode since we fail to save the Log file
	exitWithError(30, "Log file not saved.");						// MANDATORY!!!

	
	
	
	
	
// ---------------------------------------------------------
// getJsonDictFromPostContent
// ---------------------------------------------------------
function getJsonDictFromPostContent()
{	
	$jsonDictIn = null;
	
	$handle = fopen("php://input", "rw");
	if($handle){
		
		$raw_post_data = '';
		while (!feof($handle)) {
			$raw_post_data .= fread($handle, 8192); // we read 4 KB chunks by chunks
		}
		fclose($handle);
		
		$jsonDictIn = json_decode($raw_post_data, true);
	}
	
	return $jsonDictIn;
}


// ---------------------------------------------------------
// createDirIfNotExisting
// ---------------------------------------------------------
function createDirIfNotExisting($dirPath)
{
	if(file_exists($dirPath))
	{ 
		if(is_dir($dirPath)) return true;
    	return false; // $dirPath is a file. Can't override a file
    	
	} 
	else{ 
		return mkdir($dirPath, 0770, true) ;
	}
}


// ---------------------------------------------------------
// exitWithError
// ---------------------------------------------------------
// We MUST call this method before exit and pass the following 2 parameters
// which will be returned tothe application FoldersSynchronizer.
// 1) $errorCode must be a number, 0 in case of no error
// 2) $errorDescription must be a string
// The FoldersSynchronizer PostLog function expects errocCode = 0 in case of no errors.
// Any other errorCode value will be interpreted as an error occurred on this php script.
function exitWithError($errorCode, $errorDescription)
{
	$dict = array(kErrC => $errorCode, kErrD => $errorDescription);
	echo json_encode($dict);
	exit;
}
?>